@@ -16,8 +16,11 @@
 #include <set>
 #include <cassert>
 
+#include "../../min_allocator.h"
+
 int main()
 {
+    {
     typedef std::set<int> M;
     M m;
     assert(m.empty());
@@ -25,4 +28,16 @@ int main()
     assert(!m.empty());
     m.clear();
     assert(m.empty());
+    }
+#if __cplusplus >= 201103L
+    {
+    typedef std::set<int, std::less<int>, min_allocator<int>> M;
+    M m;
+    assert(m.empty());
+    m.insert(M::value_type(1));
+    assert(!m.empty());
+    m.clear();
+    assert(m.empty());
+    }
+#endif
 }
