@@ -14,6 +14,8 @@
 #include <string>
 #include <cassert>
 
+#include "../min_allocator.h"
+
 template <class S>
 void
 test(const S& s)
@@ -23,8 +25,18 @@ test(const S& s)
 
 int main()
 {
+    {
     typedef std::string S;
     test(S());
     test(S("123"));
     test(S("12345678901234567890123456789012345678901234567890"));
+    }
+#if __cplusplus >= 201103L
+    {
+    typedef std::basic_string<char, std::char_traits<char>, min_allocator<char>> S;
+    test(S());
+    test(S("123"));
+    test(S("12345678901234567890123456789012345678901234567890"));
+    }
+#endif
 }
