@@ -15,6 +15,7 @@
 #include <cassert>
 
 #include "../test_allocator.h"
+#include "../min_allocator.h"
 
 template <class S>
 void
@@ -29,9 +30,20 @@ test(S s1)
 
 int main()
 {
+    {
     typedef test_allocator<char> A;
     typedef std::basic_string<char, std::char_traits<char>, A> S;
     test(S(A(3)));
     test(S("1", A(5)));
     test(S("1234567890123456789012345678901234567890123456789012345678901234567890", A(7)));
+    }
+#if __cplusplus >= 201103L
+    {
+    typedef min_allocator<char> A;
+    typedef std::basic_string<char, std::char_traits<char>, A> S;
+    test(S(A{}));
+    test(S("1", A()));
+    test(S("1234567890123456789012345678901234567890123456789012345678901234567890", A()));
+    }
+#endif
 }
