@@ -15,6 +15,8 @@
 #include <string>
 #include <cassert>
 
+#include "../min_allocator.h"
+
 template <class S>
 void
 test(S s)
@@ -33,7 +35,16 @@ test(S s)
 
 int main()
 {
+    {
     typedef std::string S;
     test(S());
     test(S("123"));
+    }
+#if __cplusplus >= 201103L
+    {
+    typedef std::basic_string<char, std::char_traits<char>, min_allocator<char>> S;
+    test(S());
+    test(S("123"));
+    }
+#endif
 }
